netapp_ontap.models.port_lag API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.port_lag`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class PortLagSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the PortLag object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `active_ports GET`

    Active ports of a LAG (ifgrp). (Some member ports may be inactive.)

  `distribution_policy GET POST`

    Policy for mapping flows to ports for outbound packets through a LAG (ifgrp).

    Valid choices:

    - port
    - ip
    - mac
    - sequential
  `member_ports GET POST PATCH`

    The member_ports field of the port_lag.

  `mode GET POST`

    Determines how the ports interact with the switch.

    Valid choices:

    - multimode_lacp
    - multimode
    - singlemode